@@ -1,10 +1,11 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2010-2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2023 -- leonerd@leonerd.org.uk
 
-package Circle::FE::Term::Widget::Entry;
+package Circle::FE::Term::Widget::Entry 0.232470;
 
-use strict;
+use v5.26;
+use warnings;
 use constant type => "Entry";
 
 use Tickit::Widget::Entry::Plugin::Completion;
