@@ -1,10 +1,10 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2011-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2023 -- leonerd@leonerd.org.uk
 
-package Circle::FE::Term::Widget::Label;
+package Circle::FE::Term::Widget::Label 0.232470;
 
-use strict;
+use v5.26;
 use warnings;
 
 use constant type => "Label";
